@@ -1,5 +1,5 @@
 style_attr <- function(nodes, attr) {
-  style <- xml_attr(nodes, "style")
+  style <- xml2::xml_attr(nodes, "style")
   ifelse(
     grepl(sprintf("%s: [^;]*;", attr), style),
     gsub(sprintf(".*%s: ([^;]*);.*", attr), "\\1", style),
@@ -9,6 +9,6 @@ style_attr <- function(nodes, attr) {
 
 dash_array <- function(...) {
   x <- xmlSVG(mini_plot(1:3, ..., type = "l"))
-  dash <- style_attr(xml_find_first(x, "//polyline"), "stroke-dasharray")
+  dash <- style_attr(xml2::xml_find_first(x, "//polyline"), "stroke-dasharray")
   as.numeric(strsplit(dash, ",")[[1]])
 }
